@@ -84,14 +84,12 @@
      CONTINUE = 310,
      RETURN_ = 311,
      STATIC = 312,
-     PUBLIC_TOK = 313,
-     PRIVATE_TOK = 314,
-     THIS = 315,
-     EXPLICIT = 316,
-     LIT = 317,
-     PERM = 318,
-     MODIFIER = 319,
-     UNARY = 320
+     THIS = 313,
+     EXPLICIT = 314,
+     LIT = 315,
+     PERM = 316,
+     MODIFIER = 317,
+     UNARY = 318
    };
 #endif
 #define ID 258
@@ -149,14 +147,12 @@
 #define CONTINUE 310
 #define RETURN_ 311
 #define STATIC 312
-#define PUBLIC_TOK 313
-#define PRIVATE_TOK 314
-#define THIS 315
-#define EXPLICIT 316
-#define LIT 317
-#define PERM 318
-#define MODIFIER 319
-#define UNARY 320
+#define THIS 313
+#define EXPLICIT 314
+#define LIT 315
+#define PERM 316
+#define MODIFIER 317
+#define UNARY 318
 
 
 
@@ -208,7 +204,7 @@ typedef union YYSTYPE {
   absyntax::formals *fls;
 } YYSTYPE;
 /* Line 1318 of yacc.c.  */
-#line 212 "camp.tab.h"
+#line 208 "camp.tab.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
