@@ -186,6 +186,10 @@ public:
     out->write(p);
   }
   
+  virtual void writeshiftedpath(texfile *out) {
+    out->writeshifted(p);
+  }
+  
   virtual void penStart(psfile *out)
   {
     if (t())
@@ -216,7 +220,7 @@ class drawSuperPathPenBase : public drawPathPenBase {
 protected:
   vm::array *P;
   size_t size;
-  bbox bcache;
+  bbox bpath;
 
   vm::array *transpath(const transform& t) const {
     vm::array *Pt=new vm::array(size);
@@ -243,14 +247,19 @@ public:
   
   void bounds(bbox& b, iopipestream&, boxvector&, bboxlist&) {
     for(size_t i=0; i < size; i++)
-      b += vm::read<path>(P,i).bounds();
-    bcache=b;
+      bpath += vm::read<path>(P,i).bounds();
+    b += bpath;
   }
   
   void writepath(psfile *out) {
     for(size_t i=0; i < size; i++) 
       out->write(vm::read<path>(P,i),i == 0);
   }
+  
+  void writeshiftedpath(texfile *out) {
+    for(size_t i=0; i < size; i++) 
+      out->writeshifted(vm::read<path>(P,i),i == 0);
+  }
 };
  
 }
