@@ -25,8 +25,9 @@ namespace trans {
 bool entry::pr::check(action act, coder &c) {
   // We assume PUBLIC permissions and one's without an associated record are not
   // stored.
+  assert(perm!=PUBLIC && r!=0);
   return c.inTranslation(r->getLevel()) ||
-         (perm == READONLY && act != WRITE);
+         (perm == RESTRICTED && act != WRITE);
 }
 
 void entry::pr::report(action act, position pos, coder &c) {
@@ -35,18 +36,23 @@ void entry::pr::report(action act, position pos, coder &c) {
       em->error(pos);
       *em << "accessing private field outside of structure";
     }
-    else if (perm == READONLY && act == WRITE) {
+    else if (perm == RESTRICTED && act == WRITE) {
       em->error(pos);
       *em << "modifying non-public field outside of structure";
     }
   }
 }
 
-entry::entry(entry &e1, entry &e2) {
+entry::entry(entry &e1, entry &e2) : where(e2.where) {
   perms.insert(perms.end(), e1.perms.begin(), e1.perms.end());
   perms.insert(perms.end(), e2.perms.begin(), e2.perms.end());
 }
 
+entry::entry(entry &base, permission perm, record *r) : where(base.where) {
+  perms.insert(perms.end(), base.perms.begin(), base.perms.end());
+  addPerm(perm, r);
+}
+
 bool entry::checkPerm(action act, coder &c) {
   for (mem::list<pr>::iterator p=perms.begin(); p != perms.end(); ++p)
     if (!p->check(act, c))
@@ -87,19 +93,18 @@ varEntry *qualifyVarEntry(varEntry *qv, varEntry *v)
 
 tyEntry *qualifyTyEntry(varEntry *qv, tyEntry *ent)
 {
-  // Records need a varEntry that refers back to the qualifier qv.  Ie. in
+  // Records need a varEntry that refers back to the qualifier qv; i.e. in
   // the last new of the code
   //   struct A {
   //     struct B {}
   //   }
   //   A a=new A;
-  //   use a;
+  //   unravel a;
   //   new B;
-  // we need to put a's frame on the stack before allocating an instance of
-  // B.
+  // we need to put a's frame on the stack before allocating an instance of B.
   // NOTE: A possible optimization could be to only qualify the varEntry if
   // the type is a record, as other types don't use the varEntry.
-  return new tyEntry(ent->t, qualifyVarEntry(qv, ent->v));
+  return new tyEntry(ent->t, qualifyVarEntry(qv, ent->v), ent->whereDefined());
 }
 
 bool tenv::add(symbol *dest,
@@ -180,17 +185,20 @@ varEntry *venv::lookByType(symbol *name, ty *t)
   return 0;
 }
 
-void venv::list()
+void venv::list(record *module)
 {
-  // List all functions.
+  // List all functions and variables.
   for(names_t::iterator N = names.begin(); N != names.end(); ++N) {
     symbol *s=N->first;
     name_t &list=names[s];
     for(name_iterator p = list.begin(); p != list.end(); ++p) {
-      (*p)->getType()->printVar(std::cout, s);
-      std::cout << ";" << std::endl;
+      if(!module || (*p)->whereDefined() == module) {
+	(*p)->getType()->printVar(std::cout, s);
+	std::cout << ";\n";
+      }
     }
   }
+  flush(cout);
 }
 
 varEntry *venv::lookInTopScope(symbol *name, ty *t)
@@ -337,22 +345,33 @@ ty *venv::getType(symbol *name)
   return set.simplify();
 }
 
-void venv::listValues(symbol *name, values &vals) {
+void venv::listValues(symbol *name, values &vals, record *module)
+{
   ostream& out=std::cout;
 
   for(values::iterator p = vals.begin(); p != vals.end(); ++p) {
-    if ((*p)->shadowed)
-      out << "  <shadowed> ";
-    (*p)->v->getType()->printVar(out, name);
-    out << ";" << std::endl;
+    if(!module || (*p)->v->whereDefined() == module) {
+      if ((*p)->shadowed)
+	out << "  <shadowed> ";
+      (*p)->v->getType()->printVar(out, name);
+      out << ";\n";
+    }
   }
+  flush(out);
 }
 
-void venv::list()
+void venv::list(record *module)
 {
-  // List all variables.
+  // List all functions and variables.
   for(namemap::iterator N = names.begin(); N != names.end(); ++N)
-    listValues(N->first, N->second);
+    listValues(N->first, N->second,module);
+}
+
+void venv::completions(mem::list<symbol *>& l, mem::string start)
+{
+  for(namemap::iterator N = names.begin(); N != names.end(); ++N)
+    if (prefix(start, *(N->first)) && !N->second.empty())
+      l.push_back(N->first);
 }
 
 #endif // }}}
