@@ -37,7 +37,8 @@ class genv;
 // the fields of a record, whereas the derived class env is used for unqualified
 // names in translation.
 class protoenv {
-protected:
+//protected:
+public:
   // These tables keep track of type and variable definitions.
   tenv te;
   venv ve;
@@ -130,12 +131,23 @@ public:
            ve.add(src, dest, source.ve, qualifier, c);
   }
 
-  // Add the fields and types of the record given in v to the local environment.
-  void useRecord(varEntry *v);
+  // Add the standard functions for a new type.
+  void addArrayOps(types::array *t);
+  void addRecordOps(types::record *r);
+  void addFunctionOps(types::function *f);
 
-  void list()
+  void list(record *r=0)
   {
-    ve.list();
+    ve.list(r);
+  }
+
+  // Adds to a list the keywords in the environment that start with the given
+  // prefix.  Used for automatic completion at the interactive prompt.
+  typedef mem::list<symbol *> symbol_list;
+  void completions(symbol_list &l, mem::string start)
+  {
+    te.completions(l, start);
+    ve.completions(l, start);
   }
 
 private: // Non-copyable
