@@ -30,6 +30,7 @@
 #include "parser.h"
 #include "locate.h"
 #include "interact.h"
+#include "builtin.h"
 
 using namespace types;
 using settings::getSetting;
@@ -43,6 +44,9 @@ genv::genv()
   // Add settings as a module.  This is so that the init file ~/.asy/config.asy
   // can set settings.
   imap["settings"]=settings::getSettingsModule();
+#ifdef HAVE_LIBGSL  
+  imap["gsl"]=trans::getGSLModule();
+#endif  
 
   // Translate plain in advance, if we're using autoplain.
   if(getSetting<bool>("autoplain")) {
@@ -65,19 +69,8 @@ record *genv::loadModule(symbol *id, mem::string filename) {
   inTranslation.push_front(filename);
 
   em->sync();
-  
-  // Create the new module.
-  record *r = new record(id, new frame(0,0));
 
-  // Create coder and environment to translate the module.
-  // File-level modules have dynamic fields by default.
-  coder c(r, 0);
-  env e(*this);
-  coenv ce(c, e);
-
-  // Translate the abstract syntax.
-  ast->transAsFile(ce, r);
-  em->sync();
+  record *r=ast->transAsFile(*this, id);
   
   inTranslation.remove(filename);
 
