@@ -29,16 +29,18 @@ class picture : public gc {
 private:
   bool labels;
   size_t lastnumber;
+  transform *T; // Keep track of accumlative picture transform
   bbox b;
-  pair bboxshift;
-  bool epsformat,pdfformat,tgifformat;
   boxvector labelbounds;
   bboxlist bboxstack;
+  
+  static bool epsformat,pdfformat,tgifformat,pdf,Labels;
+  static double paperWidth,paperHeight;
 
 public:
   nodelist nodes;
   
-  picture() : labels(false), lastnumber(0) {}
+  picture() : labels(false), lastnumber(0), T(0) {}
   
   // Destroy all of the owned picture objects.
   ~picture();
@@ -61,16 +63,18 @@ public:
 
   void texinit();
 
+  int epstopdf(const string& epsname, const string& pdfname);
+  
   bool texprocess(const string& texname, const string& tempname,
-		  const string& prefix, const bbox& bpos); 
+		  const string& prefix, const pair& bboxshift); 
     
-  bool postprocess(const string& epsname, const string& outname, 
-		   const string& outputformat, bool wait, bool quiet,
-		   const bbox& bpos);
+  bool postprocess(const string& prename, const string& outname, 
+		   const string& outputformat, bool wait, bool view);
     
   // Ship the picture out to PostScript & TeX files.
   bool shipout(picture* preamble, const string& prefix,
-	       const string& format, bool wait, bool quiet, bool Delete=false);
+	       const string& format, bool wait, bool view=true,
+	       bool Delete=false);
  
   picture *transformed(const transform& t);
   
