@@ -17,21 +17,19 @@
 // Process the code respecting the parseonly and listvariables flags of
 // settings.
 void processCode(absyntax::block *code);
-void processString(mem::string string);
-void processFile(mem::string filename);
+void processFile(const mem::string& filename);
 void processPrompt();
 
 // Run the code in its own environment.
 void runCode(absyntax::block *code);
-void runString(mem::string string);
-void runFile(mem::string filename);
+void runString(const mem::string& s);
+void runFile(const mem::string& filename);
 void runPrompt();
 
 // Run the code in a given run-time environment.
 typedef vm::interactiveStack istack;
 void runCodeEmbedded(absyntax::block *code, trans::coenv &e, istack &s);
-void runStringEmbedded(mem::string string, trans::coenv &e, istack &s);
-void runFileEmbedded(mem::string filename, trans::coenv &e, istack &s);
+void runStringEmbedded(const mem::string& str, trans::coenv &e, istack &s);
 void runPromptEmbedded(trans::coenv &e, istack &s);
 
 // Basic listing.
