@@ -875,6 +875,10 @@ bool latex(const mem::string& texengine) {
   return texengine == "latex" || texengine == "pdflatex";
 }
 
+string nativeformat() {
+  return pdf(getSetting<mem::string>("tex")) ? "pdf" : "eps";
+}
+
 // TeX special command to set up currentmatrix for typesetting labels.
 const char *beginlabel(const mem::string& texengine) {
   if(pdf(texengine))
@@ -892,8 +896,8 @@ const char *endlabel(const mem::string& texengine) {
 // TeX special command to clip a label
 const char *clip(const mem::string& texengine) {
   if(pdf(texengine))
-    return "\\special{pdf: #3}";
-  return "\\special{ps: currentpoint currentpoint translate matrix currentmatrix\n[matrix defaultmatrix 0 get 0 0 matrix defaultmatrix 3 get\nmatrix currentmatrix 4 get matrix currentmatrix 5 get] setmatrix\n#3\nsetmatrix neg exch neg exch translate}";
+    return "\\special{pdf: #1}";
+  return "\\special{ps: currentpoint currentpoint translate matrix currentmatrix\n[matrix defaultmatrix 0 get 0 0 matrix defaultmatrix 3 get\nmatrix currentmatrix 4 get matrix currentmatrix 5 get] setmatrix\n#1\nsetmatrix neg exch neg exch translate}";
 }
 
 // Begin TeX special command.
@@ -905,13 +909,13 @@ const char *beginspecial(const mem::string& texengine) {
 
 // End TeX special command.
 const char *endspecial() {
-  return "}";
+  return "}%";
 }
 
 mem::string texengine() {
   mem::string path=getSetting<mem::string>("texpath");
   mem::string tex=getSetting<mem::string>("tex");
-  return (path == "")  ? tex : path+"/"+tex;
+  return (path == "") ? tex : (mem::string) (path+"/"+tex);
 }
 
 int getScroll() 
