@@ -11,6 +11,7 @@
 #include "callable.h"
 #include "errormsg.h"
 #include "util.h"
+#include "runtime.h"
 
 //#define DEBUG_STACK
 
@@ -25,8 +26,15 @@ void draw(ostream& out, frame *v);
 }
 #endif
 
+namespace run {
+  void breakpoint(vm::stack *Stack, absyntax::runnable *r);
+}
+
 namespace vm {
 
+using mem::list;
+list<bpinfo> bplist;
+  
 namespace {
 position curPos = position::nullPos();
 const program::label nulllabel;
@@ -39,12 +47,6 @@ inline stack::vars_t stack::make_frame(size_t size, vars_t closure)
   return vars;
 }
 
-stack::stack()
-{}
-
-stack::~stack()
-{}
-
 void run(lambda *l)
 {
   func f;
@@ -76,13 +78,64 @@ void stack::run(func *f)
   run(body->code, vars);
 }
 
+void stack::breakpoint(absyntax::runnable *r) 
+{
+  lastPos=curPos;
+  indebugger=true;
+  ::run::breakpoint(this,r);
+  mem::string s=vm::pop<mem::string>(this);
+  debugOp=(s.length() > 0) ? s[0] : (char) 0;
+  indebugger=false;
+}
+  
+void stack::debug() 
+{
+  if(indebugger || !curPos) return;
+  
+  switch(debugOp) {
+  case 'i': // inst
+      breakpoint();
+    break;
+  case 's': // step
+    if((!curPos.match(lastPos.filename()) || !curPos.match(lastPos.Line())))
+      breakpoint();
+    break;
+  case 'n': // next
+    if(curPos.match(lastPos.filename()) && !curPos.match(lastPos.Line()))
+      breakpoint();
+    break;
+  case 'f': // file
+    if(!curPos.match(lastPos.filename()))
+      breakpoint();
+    break;
+  case 'r': // return
+    if(curPos.match(breakPos.filename()))
+      breakpoint();
+    break;
+ case 'c': // continue
+  default:
+    for(list<bpinfo>::iterator p=bplist.begin(); p != bplist.end(); ++p) {
+      if(curPos.match(p->f.name()) && curPos.match(p->f.line()) &&
+	 (newline || !curPos.match(breakPos.filename()) ||
+	  !curPos.match(breakPos.Line()))) {
+	breakPos=curPos;
+	breakpoint(p->r);
+	newline=false;
+	break;
+      }
+    if(!newline && 
+       (curPos.match(lastPos.filename()) && !curPos.match(lastPos.Line())))
+       newline=true;
+    }
+    break;
+  }
+}
+  
 void stack::run(program *code, vars_t vars)
 {
   /* start the new function */
   program::label ip = code->begin();
 
-  em->Pending(settings::verbose > 4);
-  
   try {
     for (;;) {
       const inst &i = *ip;
@@ -94,7 +147,11 @@ void stack::run(program *code, vars_t vars)
       cerr << "\n";
 #endif
 
-      if(em->Pending()) em->process(curPos);
+      if(settings::verbose > 4) em->trace(curPos);
+      
+      if(!bplist.empty()) debug();
+      
+      if(errorstream::interrupt) throw interrupted();
       
       switch (i.op)
         {
@@ -276,11 +333,16 @@ position getPos() {
   return curPos;
 }
 
-void error(const char* message)
+void errornothrow(const char* message)
 {
   em->error(curPos);
   *em << message;
   em->sync();
+}
+  
+void error(const char* message)
+{
+  errornothrow(message);
   throw handled_error();
 }
   
@@ -297,3 +359,4 @@ void interactiveStack::run(lambda *codelet) {
 }
 
 } // namespace vm
+
