@@ -14,6 +14,7 @@
 #include "errormsg.h"
 #include "vm.h"
 #include "item.h"
+#include "absyn.h"
 
 namespace vm {
 
@@ -22,6 +23,26 @@ class program;
 class lambda;
 class importInitMap;
 
+struct bpinfo : public gc {
+  fileinfo f;
+  absyntax::runnable *r;
+  
+  bpinfo(const mem::string& filename, size_t lineNum,
+	 absyntax::runnable *r=NULL) :
+    f(fileinfo(filename,lineNum)), r(r) {}
+};
+  
+inline bool operator == (const bpinfo& a, const bpinfo& b)
+{
+  return a.f == b.f;
+}
+  
+extern mem::list<bpinfo> bplist;
+  
+class runnable;
+  
+extern bool indebugger;  
+  
 class stack {
 public:
   typedef frame* vars_t;
@@ -52,20 +73,41 @@ private:
   typedef mem::map<CONST mem::string,frame *> importInstanceMap;
   importInstanceMap instMap;
   
+  // One can associate an environment to embedded code while running.
+  trans::coenv *e;
+
+  // Debugger variables:
+  char debugOp;
+  position lastPos, breakPos;
+  bool newline;
+  
 public:
-  stack();
-  ~stack();
+  stack() : e(0), debugOp(0), lastPos(position::nullPos()),
+	    breakPos(position::nullPos()), newline(false) {};
+  
+  virtual ~stack() {};
 
   void setInitMap(importInitMap *i) {
     initMap=i;
   }
 
+  void setEnvironment(trans::coenv *e) {
+    this->e=e;
+  }
+
+  trans::coenv *getEnvironment() {
+    return e;
+  }
+
   // Runs the instruction listed in code, with vars as frame of variables.
   void run(program *code, vars_t vars);
 
   // Executes a function on top of the stack.
   void run(func *f);
 
+  void breakpoint(absyntax::runnable *r=NULL);
+  void debug();
+  
   // Put an import (indexed by name) on top of the stack, initializing it if
   // necessary.
   void load(mem::string index);
