@@ -69,19 +69,25 @@ void texdefines(T& out, std::list<string>& preamble=TeXpreamble,
       << "\\box\\ASYbox%" << newl
       << settings::endlabel(texengine) << "%" << newl
       << "}}" << newl
-      << "\\def\\ASYclip(#1,#2)#3{\\leavevmode%" << newl
-      << "\\put(#1,#2){" << settings::clip(texengine) << "}}" << newl;
+      << "\\def\\ASYput#1{%" << newl
+      << settings::clip(texengine) << "}" << newl;
   
   if(settings::latex(texengine)) {
-    if(pipe || !settings::getSetting<bool>("inlinetex"))
+    if(pipe || !settings::getSetting<bool>("inlinetex")) {
       out << "\\usepackage{graphicx}" << newl;
-    if(pipe) out << "\\begin{document}" << newl;
+      if(!pipe) out << "\\usepackage{color}" << newl;
+    }
+    if(pipe)
+      out << "\\begin{document}" << newl;
+  } else {
+    out << "\\input graphicx" << newl;
+    if(!pipe)
+      out << "\\input picture" << newl;
   }
 }
   
 class texfile : public psfile {
   bbox box;
-  pen lastpen;
   mem::string texengine;
 
 public:
@@ -92,6 +98,7 @@ public:
 
   void epilogue();
 
+  void setlatexcolor(pen p);
   void setpen(pen p);
   
   void gsave();
@@ -102,6 +109,10 @@ public:
   
   void closeclip();
   
+  void writeshifted(path p, bool newPath=true) {
+    write(p.transformed(shift(pair(-box.right,-box.bottom))),newPath);
+  }
+  
   // Draws label transformed by T at position z.
   void put(const string& label, const transform& T, const pair& z,
 	   const pair& Align);
